@@ -10,7 +10,8 @@ from typing import Dict, List, Union
 
 import boto3
 from localstack_client.config import get_service_port
-from moto import core as moto_core
+from moto.core import BaseModel
+from moto.core.models import InstanceTrackerMeta
 
 from localstack import config, constants
 from localstack.constants import ENV_DEV, LOCALSTACK_INFRA_PROCESS, LOCALSTACK_VENV_FOLDER
@@ -40,6 +41,7 @@ from localstack.utils.common import (
     run,
     start_thread,
 )
+from localstack.utils.patch import patch
 from localstack.utils.run import FuncThread
 from localstack.utils.server import multiserver
 from localstack.utils.testutil import is_local_test_mode
@@ -99,24 +101,26 @@ def patch_urllib3_connection_pool(**constructor_kwargs):
 
 
 def patch_instance_tracker_meta():
-    """
-    Avoid instance collection for moto dashboard
-    """
+    """Avoid instance collection for moto dashboard"""
 
-    def new_intance(meta, name, bases, dct):
-        cls = super(moto_core.models.InstanceTrackerMeta, meta).__new__(meta, name, bases, dct)
+    if hasattr(InstanceTrackerMeta, "_ls_patch_applied"):
+        return  # ensure we're not applying the patch multiple times
+
+    @patch(InstanceTrackerMeta.__new__, pass_target=False)
+    def new_instance(meta, name, bases, dct):
+        cls = super(InstanceTrackerMeta, meta).__new__(meta, name, bases, dct)
         if name == "BaseModel":
             return cls
         cls.instances = []
         return cls
 
-    moto_core.models.InstanceTrackerMeta.__new__ = new_intance
-
+    @patch(BaseModel.__new__, pass_target=False)
     def new_basemodel(cls, *args, **kwargs):
-        instance = super(moto_core.models.BaseModel, cls).__new__(cls)
+        # skip cls.instances.append(..) which is done by the original/upstream constructor
+        instance = super(BaseModel, cls).__new__(cls)
         return instance
 
-    moto_core.models.BaseModel.__new__ = new_basemodel
+    InstanceTrackerMeta._ls_patch_applied = True
 
 
 def get_multiserver_or_free_service_port():
@@ -281,13 +285,14 @@ def start_local_api(name, port, api, method, asynchronous=False):
 def stop_infra():
     if common.INFRA_STOPPED:
         return
-    common.INFRA_STOPPED = True
+    # also used to signal shutdown for edge proxy so that any further requests will be rejected
+    common.INFRA_STOPPED = True  # TODO: should probably be STOPPING since it isn't stopped yet
 
     event_publisher.fire_event(event_publisher.EVENT_STOP_INFRA)
     analytics.log.event("infra_stop")
 
     try:
-        generic_proxy.QUIET = True
+        generic_proxy.QUIET = True  # TODO: this doesn't seem to be doing anything
         LOG.debug("[shutdown] Cleaning up services ...")
         SERVICE_PLUGINS.stop_all_services()
         LOG.debug("[shutdown] Cleaning up files ...")
@@ -331,7 +336,7 @@ def terminate_all_processes_in_docker():
         return
     print("INFO: Received command to restart all processes ...")
     cmd = (
-        'ps aux | grep -v supervisor | grep -v docker-entrypoint.sh | grep -v "make infra" | '
+        'ps aux | grep -v supervisor | grep -v docker-entrypoint.sh | grep -v "bin/localstack" | '
         "grep -v localstack_infra.log | awk '{print $1}' | grep -v PID"
     )
     pids = run(cmd).strip()
@@ -404,6 +409,8 @@ def start_infra(asynchronous=False, apis=None):
         # set up logging
         setup_logging()
 
+        # run hooks, to allow them to apply patches and changes
+        hooks.on_infra_start.run()
         # with changes that hooks have made, now start the infrastructure
         thread = do_start_infra(asynchronous, apis, is_in_docker)
 
@@ -426,7 +433,6 @@ def start_infra(asynchronous=False, apis=None):
 
 
 def do_start_infra(asynchronous, apis, is_in_docker):
-    hooks.on_infra_start.run()
 
     event_publisher.fire_event(
         event_publisher.EVENT_START_INFRA,
