@@ -89,6 +89,8 @@ class SdkDockerClient(ContainerClient):
             container = self.client().containers.get(container_name)
             if container.status == "running":
                 return DockerContainerStatus.UP
+            elif container.status == "paused":
+                return DockerContainerStatus.PAUSED
             else:
                 return DockerContainerStatus.DOWN
         except NotFound:
@@ -108,6 +110,16 @@ class SdkDockerClient(ContainerClient):
         except APIError:
             raise ContainerException()
 
+    def pause_container(self, container_name: str) -> None:
+        LOG.debug("Pausing container: %s", container_name)
+        try:
+            container = self.client().containers.get(container_name)
+            container.pause()
+        except NotFound:
+            raise NoSuchContainer(container_name)
+        except APIError:
+            raise ContainerException()
+
     def remove_container(self, container_name: str, force=True, check_existence=False) -> None:
         LOG.debug("Removing container: %s", container_name)
         if check_existence and container_name not in self.get_running_container_names():
